@@ -17,23 +17,33 @@ class Database:
     """
     Class for DB operations
     """
-    # Class static variables used for database host ip and port information, database name
-    # Static variables are referred to by using <class_name>.<variable_name>
+    # Class variables used for database host ip and port information, database name
+    # variables are referred to by using <class_name>.<variable_name>
     # AK_URI = "mongodb+srv://apache_abhinav_official:6g6RRf2UZiJy8G2" \
     #          "@taxiops.jdfqcmn.mongodb.net/?retryWrites=true&w=majority"
     # AK_DB_NAME = 'TaxiOps'
+    # _instance = None initially
+    # _db_conn = database connection client
+    # _db = database
+    # _logger = applevel logger
 
     DB_URI = "mongodb+srv://iitmcloudfeb22g1:iitmcloudfeb22g1@spn.xqzqo3y.mongodb.net/" \
              "?retryWrites=true&w=majority"
     DB_NAME = 'ProjectTaxi'
+    _instance = None
+    _db_conn = MongoClient(DB_URI)
+    _db = _db_conn[DB_NAME]
+    _logger = TaxiOpsLogger()
 
-    def __init__(self):
+    def __new__(cls):
         """
-        The constructor for Database class.
+        making database object singleton class
+        :return: Database instance
         """
-        self._db_conn = MongoClient(Database.DB_URI)
-        self._db = self._db_conn[Database.DB_NAME]
-        self._logger = TaxiOpsLogger()
+        if cls._instance is None:
+            cls._logger.info('Creating the database instance')
+            cls._instance = super(Database, cls).__new__(cls)
+        return cls._instance
 
     def find_one(self, collection, key):
         """
@@ -82,7 +92,7 @@ class Database:
         # if an index of the same specification does not already exist.
         # https://www.mongodb.com/docs/manual/indexes/
         if index_key != "":
-            self.__create_geo_spatial_index(collection, index_key)
+            self.__create_geo_spatial_index(self._db[collection], index_key)
         return document.inserted_id
 
     def insert_multiple(self, collection, data, index_key: str = ""):
